<?php

/*
+---------------------------------------------------------------------------+
| Revive Adserver                                                           |
| http://www.revive-adserver.com                                            |
|                                                                           |
| Copyright: See the COPYRIGHT.txt file.                                    |
| License: GPLv2 or later, see the LICENSE.txt file.                        |
+---------------------------------------------------------------------------+
*/

/**
 * @package    OpenXPlugin
 * @subpackage InvocationTags
 *
 */

require_once LIB_PATH . '/Extension/invocationTags/InvocationTags.php';
require_once MAX_PATH . '/lib/max/Plugin/Translation.php';

/**
 *
 * Invocation tag plugin.
 *
 */
class Plugins_InvocationTags_OxInvocationTags_gtag extends Plugins_InvocationTags
{
    /**
     * Return name of plugin
     *
     * @return string
     */
    public function getName()
    {
        return $this->translate("Banner Waterfall");
    }

    /**
     * Return the English name of the plugin. Used when
     * generating translation keys based on the plugin
     * name.
     *
     * @return string An English string describing the class.
     */
    public function getNameEN()
    {
        return 'Gtag Ads';
    }

    /**
     * Check if plugin is allowed
     *
     * @return boolean  True - allowed, false - not allowed
     */
    public function isAllowed($extra = null)
    {
        $isAllowed = parent::isAllowed($extra);
        return true;
    }

    public function getOrder()
    {
        parent::getOrder();
        return 40;
    }

    /**
     * Return list of options
     *
     * @return array    Group of options
     */
    public function getOptionsList()
    {
        if (is_array($this->defaultOptions)) {
            if (in_array('cacheBuster', $this->defaultOptions)) {
                unset($this->defaultOptions['cacheBuster']);
            }
        }
        
        $options = [];

        return $options;
    }

    /**
     * Return invocation code for this plugin (codetype)
     *
     * @return string
     */
    
    public function generateInvocationCode()
    {
        $aComments = [
            'Comment' => $this->translate("
  * This noscript section of this tag only shows image banners. There
  * is no width or height in these banners, so if you want these tags to
  * allocate space for the ad before it shows, you will need to add this
  * information to the <img> tag.
  *
  * If you do not want to deal with the intricities of the noscript
  * section, delete the tag (from <noscript>... to </noscript>). On
  * average, the noscript tag is called from less than 1% of internet
  * users."),
            ];
        parent::prepareCommonInvocationData($aComments);

        $conf = $GLOBALS['_MAX']['CONF'];
        $mi = &$this->maxInvocation;
      
		$buffer = $mi->buffer;

        $affiliateid = $mi->affiliateid;
		$zoneid = $mi->zoneid;

		if ($GLOBALS['_MAX']['SSL_REQUEST']) 
		{
			$djprotocol='https://';
		}
		else
		{
			$djprotocol='http://';
		}
        
        $file_path = $djprotocol . $GLOBALS['_MAX']['CONF']['webpath']['delivery'];

        $buffer .= "<script type='text/javascript'>\n";
        $buffer .= "var xmlHttp = new XMLHttpRequest();\n";
        $buffer .= "xmlHttp.open('POST',";
        $buffer .= "'" . $file_path . "/g-tag.php?";
        $buffer .= "affiliateid=".$affiliateid;
        $buffer .= "&zoneid=".$zoneid."', false);\n";
        $buffer .= "xmlHttp.getResponseHeader('Content-type', 'application/json');\n";
        $buffer .= "xmlHttp.send( null );\n";
        $buffer .= "if(xmlHttp.responseText!='' && xmlHttp.responseText!=null && xmlHttp.responseText!='undefined'){\n";
        $buffer .= "document.write (xmlHttp.responseText);\n";
        $buffer .= "}\n";
        $buffer .= "</script>";
        
        return $buffer;
    }

    public function setInvocation(&$invocation)
    {
        $this->maxInvocation = &$invocation;
        $this->maxInvocation->canDetectCharset = true;
    }

}

